@@ -403,9 +403,9 @@ task_editor_send_comp (CompEditor *editor,
 		gboolean result;
 
 		client = e_meeting_store_get_client (priv->model);
-		result = itip_send_comp (
+		result = itip_send_comp_sync (
 			registry, E_CAL_COMPONENT_METHOD_CANCEL, comp,
-			client, NULL, NULL, NULL, strip_alarms, FALSE);
+			client, NULL, NULL, NULL, strip_alarms, FALSE, NULL, NULL);
 		g_object_unref (comp);
 
 		if (!result)
