@@ -528,6 +528,7 @@ task_page_finalize (GObject *object)
 
 	g_strfreev (priv->address_strings);
 	g_free (priv->fallback_address);
+	g_free (priv->user_add);
 
 	g_ptr_array_foreach (
 		priv->deleted_attendees, (GFunc) g_object_unref, NULL);
@@ -745,6 +746,7 @@ task_page_fill_widgets (CompEditorPage *page,
 		gchar *name = NULL;
 		gchar *mailto = NULL;
 
+		g_free (priv->user_add);
 		priv->user_add = itip_get_comp_attendee (
 			registry, comp, client);
 
@@ -2673,10 +2675,12 @@ task_page_construct (TaskPage *tpage,
 
 	/* Make sure our custom widget classes are registered with
 	 * GType before we load the GtkBuilder definition file. */
+	g_type_ensure (E_TYPE_CLIENT_COMBO_BOX);
 	g_type_ensure (E_TYPE_DATE_EDIT);
 	g_type_ensure (E_TYPE_TIMEZONE_ENTRY);
 	g_type_ensure (E_TYPE_SOURCE_COMBO_BOX);
 	g_type_ensure (E_TYPE_SPELL_ENTRY);
+	g_type_ensure (E_TYPE_URL_ENTRY);
 
 	priv->builder = gtk_builder_new ();
 	e_load_ui_builder_definition (priv->builder, "task-page.ui");
