@@ -132,7 +132,7 @@ itip_get_user_identities (ESourceRegistry *registry)
 
 	extension_name = E_SOURCE_EXTENSION_MAIL_IDENTITY;
 
-	list = e_source_registry_list_sources (registry, extension_name);
+	list = e_source_registry_list_enabled (registry, extension_name);
 
 	identities = g_new0 (gchar *, g_list_length (list) + 1);
 
@@ -1772,7 +1772,7 @@ itip_send_component_finish (ItipSendComponentData *isc)
 
 	isc->success = FALSE;
 
-	settings = g_settings_new ("org.gnome.evolution.calendar");
+	settings = e_util_ref_settings ("org.gnome.evolution.calendar");
 	use_24hour_format = g_settings_get_boolean (settings, "use-24hour-format");
 	g_object_unref (settings);
 
