@@ -56,6 +56,18 @@
 	E_COMPOSER_ACTION ((composer), "smime-encrypt")
 #define E_COMPOSER_ACTION_SMIME_SIGN(composer) \
 	E_COMPOSER_ACTION ((composer), "smime-sign")
+#define E_COMPOSER_ACTION_TOOLBAR_PGP_ENCRYPT(composer) \
+	E_COMPOSER_ACTION ((composer), "toolbar-pgp-encrypt")
+#define E_COMPOSER_ACTION_TOOLBAR_PGP_SIGN(composer) \
+	E_COMPOSER_ACTION ((composer), "toolbar-pgp-sign")
+#define E_COMPOSER_ACTION_TOOLBAR_PRIORITIZE_MESSAGE(composer) \
+	E_COMPOSER_ACTION ((composer), "toolbar-prioritize-message")
+#define E_COMPOSER_ACTION_TOOLBAR_REQUEST_READ_RECEIPT(composer) \
+	E_COMPOSER_ACTION ((composer), "toolbar-request-read-receipt")
+#define E_COMPOSER_ACTION_TOOLBAR_SMIME_ENCRYPT(composer) \
+	E_COMPOSER_ACTION ((composer), "toolbar-smime-encrypt")
+#define E_COMPOSER_ACTION_TOOLBAR_SMIME_SIGN(composer) \
+	E_COMPOSER_ACTION ((composer), "toolbar-smime-sign")
 #define E_COMPOSER_ACTION_VIEW_BCC(composer) \
 	E_COMPOSER_ACTION ((composer), "view-bcc")
 #define E_COMPOSER_ACTION_VIEW_CC(composer) \
