@@ -29,6 +29,7 @@
 #include "e-attachment-store.h"
 #include "e-attachment-icon-view.h"
 #include "e-attachment-tree-view.h"
+#include "e-misc-utils.h"
 
 #define E_ATTACHMENT_BAR_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
@@ -132,12 +133,12 @@ attachment_bar_set_store (EAttachmentBar *bar,
 		GTK_TREE_VIEW (bar->priv->tree_view),
 		bar->priv->model);
 
-	g_signal_connect_object (
+	e_signal_connect_notify_object (
 		bar->priv->model, "notify::num-attachments",
 		G_CALLBACK (attachment_bar_update_status), bar,
 		G_CONNECT_SWAPPED);
 
-	g_signal_connect_object (
+	e_signal_connect_notify_object (
 		bar->priv->model, "notify::total-size",
 		G_CALLBACK (attachment_bar_update_status), bar,
 		G_CONNECT_SWAPPED);
@@ -360,7 +361,7 @@ attachment_bar_constructed (GObject *object)
 		G_BINDING_SYNC_CREATE);
 
 	/* Set up property-to-GSettings bindings. */
-	settings = g_settings_new ("org.gnome.evolution.shell");
+	settings = e_util_ref_settings ("org.gnome.evolution.shell");
 	g_settings_bind (
 		settings, "attachment-view",
 		object, "active-view",
