@@ -34,6 +34,7 @@
 #include "e-emoticon-chooser.h"
 #include "e-image-chooser-dialog.h"
 #include "e-spell-checker.h"
+#include "e-misc-utils.h"
 
 static void
 insert_html_file_ready_cb (GFile *file,
@@ -425,23 +426,30 @@ static void
 action_copy_cb (GtkAction *action,
                 EHTMLEditor *editor)
 {
-	webkit_web_view_copy_clipboard (
-		WEBKIT_WEB_VIEW (e_html_editor_get_view (editor)));
+	EHTMLEditorView *view = e_html_editor_get_view (editor);
+
+	if (gtk_widget_has_focus (GTK_WIDGET (view)))
+		webkit_web_view_copy_clipboard (WEBKIT_WEB_VIEW (view));
 }
 
 static void
 action_cut_cb (GtkAction *action,
                EHTMLEditor *editor)
 {
-	webkit_web_view_cut_clipboard (
-		WEBKIT_WEB_VIEW (e_html_editor_get_view (editor)));
+	EHTMLEditorView *view = e_html_editor_get_view (editor);
+
+	if (gtk_widget_has_focus (GTK_WIDGET (view)))
+		webkit_web_view_cut_clipboard (WEBKIT_WEB_VIEW (view));
 }
 
 static void
 action_indent_cb (GtkAction *action,
                   EHTMLEditor *editor)
 {
-	e_html_editor_selection_indent (editor->priv->selection);
+	EHTMLEditorView *view = e_html_editor_get_view (editor);
+
+	if (gtk_widget_has_focus (GTK_WIDGET (view)))
+		e_html_editor_selection_indent (editor->priv->selection);
 }
 
 static void
@@ -631,7 +639,7 @@ update_mode_combobox (gpointer data)
 	is_html = e_html_editor_view_get_html_mode (view);
 
 	action = gtk_action_group_get_action (
-		editor->priv->core_actions, "mode-html");
+		editor->priv->core_editor_actions, "mode-html");
 	gtk_radio_action_set_current_value (
 		GTK_RADIO_ACTION (action), (is_html ? 1 : 0));
 
@@ -697,11 +705,11 @@ action_paste_cb (GtkAction *action,
 	EHTMLEditorView *view = e_html_editor_get_view (editor);
 
 	/* If WebView doesn't have focus, focus it */
-	if (gtk_widget_has_focus (GTK_WIDGET (view)))
-		gtk_widget_grab_focus (GTK_WIDGET (view));
+	if (gtk_widget_has_focus (GTK_WIDGET (view))) {
+		webkit_web_view_paste_clipboard (WEBKIT_WEB_VIEW (view));
 
-	webkit_web_view_paste_clipboard (WEBKIT_WEB_VIEW (view));
-	e_html_editor_view_force_spell_check (view);
+		e_html_editor_view_force_spell_check (view);
+	}
 }
 
 static void
@@ -710,8 +718,10 @@ action_paste_as_text_cb (GtkAction *action,
 {
 	EHTMLEditorView *view = e_html_editor_get_view (editor);
 
-	e_html_editor_view_paste_as_text (view);
-	e_html_editor_view_force_spell_check (view);
+	if (gtk_widget_has_focus (GTK_WIDGET (view))) {
+		e_html_editor_view_paste_as_text (view);
+		e_html_editor_view_force_spell_check (view);
+	}
 }
 
 static void
@@ -720,8 +730,10 @@ action_paste_quote_cb (GtkAction *action,
 {
 	EHTMLEditorView *view = e_html_editor_get_view (editor);
 
-	e_html_editor_view_paste_clipboard_quoted (view);
-	e_html_editor_view_force_spell_check (view);
+	if (gtk_widget_has_focus (GTK_WIDGET (view))) {
+		e_html_editor_view_paste_clipboard_quoted (view);
+		e_html_editor_view_force_spell_check (view);
+	}
 }
 
 static void
@@ -828,16 +840,20 @@ static void
 action_redo_cb (GtkAction *action,
                 EHTMLEditor *editor)
 {
-	webkit_web_view_redo (
-		WEBKIT_WEB_VIEW (e_html_editor_get_view (editor)));
+	EHTMLEditorView *view = e_html_editor_get_view (editor);
+
+	if (gtk_widget_has_focus (GTK_WIDGET (view)))
+		webkit_web_view_redo (WEBKIT_WEB_VIEW (view));
 }
 
 static void
 action_select_all_cb (GtkAction *action,
                       EHTMLEditor *editor)
 {
-	webkit_web_view_select_all (
-		WEBKIT_WEB_VIEW (e_html_editor_get_view (editor)));
+	EHTMLEditorView *view = e_html_editor_get_view (editor);
+
+	if (gtk_widget_has_focus (GTK_WIDGET (view)))
+		webkit_web_view_select_all (WEBKIT_WEB_VIEW (view));
 }
 
 static void
@@ -856,9 +872,8 @@ static void
 action_find_again_cb (GtkAction *action,
                       EHTMLEditor *editor)
 {
-	if (editor->priv->find_dialog == NULL) {
+	if (editor->priv->find_dialog == NULL)
 		return;
-	}
 
 	e_html_editor_find_dialog_find_next (
 		E_HTML_EDITOR_FIND_DIALOG (editor->priv->find_dialog));
@@ -892,22 +907,30 @@ static void
 action_undo_cb (GtkAction *action,
                 EHTMLEditor *editor)
 {
-	webkit_web_view_undo (
-		WEBKIT_WEB_VIEW (e_html_editor_get_view (editor)));
+	EHTMLEditorView *view = e_html_editor_get_view (editor);
+
+	if (gtk_widget_has_focus (GTK_WIDGET (view)))
+		webkit_web_view_undo (WEBKIT_WEB_VIEW (view));
 }
 
 static void
 action_unindent_cb (GtkAction *action,
                     EHTMLEditor *editor)
 {
-	e_html_editor_selection_unindent (editor->priv->selection);
+	EHTMLEditorView *view = e_html_editor_get_view (editor);
+
+	if (gtk_widget_has_focus (GTK_WIDGET (view)))
+		e_html_editor_selection_unindent (editor->priv->selection);
 }
 
 static void
 action_wrap_lines_cb (GtkAction *action,
                       EHTMLEditor *editor)
 {
-	e_html_editor_selection_wrap_lines (editor->priv->selection);
+	EHTMLEditorView *view = e_html_editor_get_view (editor);
+
+	if (gtk_widget_has_focus (GTK_WIDGET (view)))
+		e_html_editor_selection_wrap_lines (editor->priv->selection);
 }
 
 static void
@@ -945,27 +968,6 @@ static GtkActionEntry core_entries[] = {
 	  N_("Cut selected text to the clipboard"),
 	  G_CALLBACK (action_cut_cb) },
 
-	{ "indent",
-	  "format-indent-more",
-	  N_("_Increase Indent"),
-	  "<Control>bracketright",
-	  N_("Increase Indent"),
-	  G_CALLBACK (action_indent_cb) },
-
-	{ "insert-html-file",
-	  NULL,
-	  N_("_HTML File..."),
-	  NULL,
-	  NULL,
-	  G_CALLBACK (action_insert_html_file_cb) },
-
-	{ "insert-text-file",
-	  NULL,
-	  N_("Te_xt File..."),
-	  NULL,
-	  NULL,
-	  G_CALLBACK (action_insert_text_file_cb) },
-
 	{ "paste",
 	  "edit-paste",
 	  N_("_Paste"),
@@ -973,13 +975,6 @@ static GtkActionEntry core_entries[] = {
 	  N_("Paste text from the clipboard"),
 	  G_CALLBACK (action_paste_cb) },
 
-	{ "paste-quote",
-	  NULL,
-	  N_("Paste _Quotation"),
-	  "<Shift><Control>v",
-	  NULL,
-	  G_CALLBACK (action_paste_quote_cb) },
-
 	{ "redo",
 	  "edit-redo",
 	  N_("_Redo"),
@@ -994,34 +989,6 @@ static GtkActionEntry core_entries[] = {
 	  NULL,
 	  G_CALLBACK (action_select_all_cb) },
 
-	{ "show-find",
-	  "edit-find",
-	  N_("_Find..."),
-	  "<Control>f",
-	  N_("Search for text"),
-	  G_CALLBACK (action_show_find_cb) },
-
-	{ "find-again",
-	  NULL,
-	  N_("Find A_gain"),
-	  "<Control>g",
-	  NULL,
-	  G_CALLBACK (action_find_again_cb) },
-
-	{ "show-replace",
-	  "edit-find-replace",
-	  N_("Re_place..."),
-	  "<Control>h",
-	  N_("Search for and replace text"),
-	  G_CALLBACK (action_show_replace_cb) },
-
-	{ "spell-check",
-	  "tools-check-spelling",
-	  N_("Check _Spelling..."),
-	  "F7",
-	  NULL,
-	  G_CALLBACK (action_spell_check_cb) },
-
 	{ "undo",
 	  "edit-undo",
 	  N_("_Undo"),
@@ -1029,27 +996,6 @@ static GtkActionEntry core_entries[] = {
 	  N_("Undo the last action"),
 	  G_CALLBACK (action_undo_cb) },
 
-	{ "unindent",
-	  "format-indent-less",
-	  N_("_Decrease Indent"),
-	  "<Control>bracketleft",
-	  N_("Decrease Indent"),
-	  G_CALLBACK (action_unindent_cb) },
-
-	{ "wrap-lines",
-	  NULL,
-	  N_("_Wrap Lines"),
-	  "<Control>k",
-	  NULL,
-	  G_CALLBACK (action_wrap_lines_cb) },
-
-	{ "webkit-inspector",
-          NULL,
-          N_("Open Inspector"),
-          NULL,
-          NULL,
-          G_CALLBACK (action_show_webkit_inspector_cb) },
-
 	/* Menus */
 
 	{ "edit-menu",
@@ -1109,6 +1055,86 @@ static GtkActionEntry core_entries[] = {
 	  NULL }
 };
 
+static GtkActionEntry core_editor_entries[] = {
+
+	{ "indent",
+	  "format-indent-more",
+	  N_("_Increase Indent"),
+	  "<Control>bracketright",
+	  N_("Increase Indent"),
+	  G_CALLBACK (action_indent_cb) },
+
+	{ "insert-html-file",
+	  NULL,
+	  N_("_HTML File..."),
+	  NULL,
+	  NULL,
+	  G_CALLBACK (action_insert_html_file_cb) },
+
+	{ "insert-text-file",
+	  NULL,
+	  N_("Te_xt File..."),
+	  NULL,
+	  NULL,
+	  G_CALLBACK (action_insert_text_file_cb) },
+
+	{ "paste-quote",
+	  NULL,
+	  N_("Paste _Quotation"),
+	  "<Shift><Control>v",
+	  NULL,
+	  G_CALLBACK (action_paste_quote_cb) },
+
+	{ "show-find",
+	  "edit-find",
+	  N_("_Find..."),
+	  "<Control>f",
+	  N_("Search for text"),
+	  G_CALLBACK (action_show_find_cb) },
+
+	{ "find-again",
+	  NULL,
+	  N_("Find A_gain"),
+	  "<Control>g",
+	  NULL,
+	  G_CALLBACK (action_find_again_cb) },
+
+	{ "show-replace",
+	  "edit-find-replace",
+	  N_("Re_place..."),
+	  "<Control>h",
+	  N_("Search for and replace text"),
+	  G_CALLBACK (action_show_replace_cb) },
+
+	{ "spell-check",
+	  "tools-check-spelling",
+	  N_("Check _Spelling..."),
+	  "F7",
+	  NULL,
+	  G_CALLBACK (action_spell_check_cb) },
+
+	{ "unindent",
+	  "format-indent-less",
+	  N_("_Decrease Indent"),
+	  "<Control>bracketleft",
+	  N_("Decrease Indent"),
+	  G_CALLBACK (action_unindent_cb) },
+
+	{ "wrap-lines",
+	  NULL,
+	  N_("_Wrap Lines"),
+	  "<Control>k",
+	  NULL,
+	  G_CALLBACK (action_wrap_lines_cb) },
+
+	{ "webkit-inspector",
+          NULL,
+          N_("Open Inspector"),
+          NULL,
+          NULL,
+          G_CALLBACK (action_show_webkit_inspector_cb) },
+};
+
 static GtkRadioActionEntry core_justify_entries[] = {
 
 	{ "justify-center",
@@ -1842,6 +1868,13 @@ editor_actions_init (EHTMLEditor *editor)
 	gtk_action_group_add_actions (
 		action_group, core_entries,
 		G_N_ELEMENTS (core_entries), editor);
+	gtk_ui_manager_insert_action_group (manager, action_group, 0);
+
+	action_group = editor->priv->core_editor_actions;
+	gtk_action_group_set_translation_domain (action_group, domain);
+	gtk_action_group_add_actions (
+		action_group, core_editor_entries,
+		G_N_ELEMENTS (core_editor_entries), editor);
 	gtk_action_group_add_radio_actions (
 		action_group, core_justify_entries,
 		G_N_ELEMENTS (core_justify_entries),
@@ -2020,7 +2053,7 @@ editor_actions_init (EHTMLEditor *editor)
 	/* Disable all actions and toolbars when editor is not editable */
 	g_object_bind_property (
 		view, "editable",
-		editor->priv->core_actions, "sensitive",
+		editor->priv->core_editor_actions, "sensitive",
 		G_BINDING_SYNC_CREATE);
 	g_object_bind_property (
 		view, "editable",
@@ -2035,7 +2068,7 @@ editor_actions_init (EHTMLEditor *editor)
 		editor->priv->suggestion_actions, "sensitive",
 		G_BINDING_SYNC_CREATE);
 
-	settings = g_settings_new ("org.gnome.evolution.mail");
+	settings = e_util_ref_settings ("org.gnome.evolution.mail");
 	gtk_action_set_visible (
 		ACTION (WEBKIT_INSPECTOR),
 		g_settings_get_boolean (settings, "composer-developer-mode"));
