@@ -1,16 +1,15 @@
 /*
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) version 3.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
@@ -29,6 +28,7 @@
 
 #include "e-plugin.h"
 #include "e-util-private.h"
+#include "e-misc-utils.h"
 
 /* plugin debug */
 #define pd(x)
@@ -122,7 +122,7 @@ ep_set_enabled (const gchar *id,
 	} else
 		ep_disabled = g_slist_prepend (ep_disabled, g_strdup (id));
 
-	settings = g_settings_new ("org.gnome.evolution");
+	settings = e_util_ref_settings ("org.gnome.evolution");
 	array = g_ptr_array_new ();
 	for (link = ep_disabled; link != NULL; link = link->next)
 		g_ptr_array_add (array, link->data);
@@ -506,7 +506,7 @@ e_plugin_load_plugins (void)
 		E_TYPE_PLUGIN_HOOK, (ETypeFunc)
 		plugin_hook_load_subclass, eph_types);
 
-	settings = g_settings_new ("org.gnome.evolution");
+	settings = e_util_ref_settings ("org.gnome.evolution");
 	strv = g_settings_get_strv (settings, "disabled-eplugins");
 	for (i = 0, ep_disabled = NULL; strv[i] != NULL; i++)
 		ep_disabled = g_slist_append (ep_disabled, g_strdup (strv[i]));
