@@ -300,7 +300,7 @@ handle_http_request (GSimpleAsyncResult *res,
 	if (!e_shell_get_online (shell))
 		goto cleanup;
 
-	settings = g_settings_new ("org.gnome.evolution.mail");
+	settings = e_util_ref_settings ("org.gnome.evolution.mail");
 	image_policy = g_settings_get_enum (settings, "image-loading-policy");
 	g_object_unref (settings);
 
