@@ -88,7 +88,9 @@ enum {
 	E_MAIL_READER_SELECTION_IS_MAILING_LIST = 1 << 16,
 	E_MAIL_READER_FOLDER_IS_JUNK = 1 << 17,
 	E_MAIL_READER_FOLDER_IS_VTRASH = 1 << 18,
-	E_MAIL_READER_FOLDER_ARCHIVE_FOLDER_SET = 1 << 19
+	E_MAIL_READER_FOLDER_ARCHIVE_FOLDER_SET = 1 << 19,
+	E_MAIL_READER_SELECTION_HAS_IGNORE_THREAD = 1 << 20,
+	E_MAIL_READER_SELECTION_HAS_NOTIGNORE_THREAD = 1 << 21
 };
 
 struct _EMailReaderInterface {
