@@ -228,7 +228,7 @@ main_get_filter_driver (CamelSession *session,
 
 	priv = E_MAIL_UI_SESSION_GET_PRIVATE (session);
 
-	settings = g_settings_new ("org.gnome.evolution.mail");
+	settings = e_util_ref_settings ("org.gnome.evolution.mail");
 
 	config_dir = mail_session_get_config_dir ();
 	user = g_build_filename (config_dir, "filters.xml", NULL);
@@ -631,12 +631,16 @@ mail_ui_session_user_alert (CamelSession *session,
 	g_free (display_name);
 }
 
+extern gint camel_application_is_exiting;
+
 static void
 mail_ui_session_refresh_service (EMailSession *session,
                                  CamelService *service)
 {
-	if (camel_session_get_online (CAMEL_SESSION (session)))
+	if (!camel_application_is_exiting &&
+	    camel_session_get_online (CAMEL_SESSION (session))) {
 		mail_receive_service (service);
+	}
 }
 
 static EMVFolderContext *
