@@ -252,6 +252,9 @@ folder_selector_dispose (GObject *object)
 
 	priv = EM_FOLDER_SELECTOR_GET_PRIVATE (object);
 
+	if (priv->model && priv->model != em_folder_tree_model_get_default ())
+		em_folder_tree_model_remove_all_stores (priv->model);
+
 	g_clear_object (&priv->model);
 	g_clear_object (&priv->alert_bar);
 	g_clear_object (&priv->activity_bar);
@@ -341,6 +344,7 @@ folder_selector_constructed (GObject *object)
 	widget = e_tree_view_frame_new ();
 	gtk_box_pack_end (GTK_BOX (container), widget, TRUE, TRUE, 0);
 	selector->priv->tree_view_frame = g_object_ref (widget);
+	gtk_widget_set_size_request (widget, -1, 240);
 	gtk_widget_show (widget);
 
 	g_signal_connect (
