@@ -1,5 +1,6 @@
 /*
- * e-cal-shell-view.c
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * Copyright (C) 2014 Red Hat, Inc. (www.redhat.com)
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -7,29 +8,30 @@
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include <gtk/gtk.h>
+#include <glib/gi18n-lib.h>
+
 #include "e-cal-shell-view-private.h"
 
+#include "calendar/gui/ea-calendar.h"
 #include "calendar/gui/calendar-view.h"
 
-G_DEFINE_DYNAMIC_TYPE (
-	ECalShellView,
-	e_cal_shell_view,
-	E_TYPE_SHELL_VIEW)
+#include "e-cal-base-shell-sidebar.h"
+#include "e-cal-shell-content.h"
+#include "e-cal-shell-view.h"
+
+G_DEFINE_DYNAMIC_TYPE (ECalShellView, e_cal_shell_view, E_TYPE_CAL_BASE_SHELL_VIEW)
 
 static void
 cal_shell_view_add_action_button (GtkBox *box,
@@ -76,83 +78,18 @@ cal_shell_view_prepare_for_quit_cb (EShell *shell,
 	e_cal_shell_view_search_stop (cal_shell_view);
 }
 
-static void
-cal_shell_view_dispose (GObject *object)
-{
-	e_cal_shell_view_private_dispose (E_CAL_SHELL_VIEW (object));
-
-	/* Chain up to parent's dispose() method. */
-	G_OBJECT_CLASS (e_cal_shell_view_parent_class)->dispose (object);
-}
-
-static void
-cal_shell_view_finalize (GObject *object)
-{
-	e_cal_shell_view_private_finalize (E_CAL_SHELL_VIEW (object));
-
-	/* Chain up to parent's finalize() method. */
-	G_OBJECT_CLASS (e_cal_shell_view_parent_class)->finalize (object);
-}
-
-static void
-cal_shell_view_constructed (GObject *object)
-{
-	EShell *shell;
-	EShellView *shell_view;
-	EShellWindow *shell_window;
-	EShellSearchbar *searchbar;
-	ECalShellView *cal_shell_view;
-	ECalShellContent *cal_shell_content;
-	GtkWidget *container;
-	GtkWidget *widget;
-	gulong handler_id;
-
-	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_cal_shell_view_parent_class)->constructed (object);
-
-	cal_shell_view = E_CAL_SHELL_VIEW (object);
-	e_cal_shell_view_private_constructed (cal_shell_view);
-
-	shell_view = E_SHELL_VIEW (cal_shell_view);
-	shell_window = e_shell_view_get_shell_window (shell_view);
-	shell = e_shell_window_get_shell (shell_window);
-
-	cal_shell_content = cal_shell_view->priv->cal_shell_content;
-	searchbar = e_cal_shell_content_get_searchbar (cal_shell_content);
-	container = e_shell_searchbar_get_search_box (searchbar);
-
-	widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	cal_shell_view_add_action_button (
-		GTK_BOX (widget), ACTION (CALENDAR_SEARCH_PREV));
-	cal_shell_view_add_action_button (
-		GTK_BOX (widget), ACTION (CALENDAR_SEARCH_NEXT));
-	cal_shell_view_add_action_button (
-		GTK_BOX (widget), ACTION (CALENDAR_SEARCH_STOP));
-	gtk_container_add (GTK_CONTAINER (container), widget);
-	gtk_widget_show (widget);
-
-	handler_id = g_signal_connect (
-		shell, "prepare-for-quit",
-		G_CALLBACK (cal_shell_view_prepare_for_quit_cb),
-		cal_shell_view);
-
-	cal_shell_view->priv->shell = g_object_ref (shell);
-	cal_shell_view->priv->prepare_for_quit_handler_id = handler_id;
-}
-
 static void
 cal_shell_view_execute_search (EShellView *shell_view)
 {
 	ECalShellContent *cal_shell_content;
-	ECalShellSidebar *cal_shell_sidebar;
+	ECalBaseShellSidebar *cal_shell_sidebar;
 	EShellWindow *shell_window;
 	EShellContent *shell_content;
 	EShellSidebar *shell_sidebar;
 	EShellSearchbar *searchbar;
 	EActionComboBox *combo_box;
-	GnomeCalendar *calendar;
-	ECalendar *date_navigator;
-	ECalModel *model;
+	ECalendar *calendar;
+	ECalDataModel *data_model;
 	GtkRadioAction *action;
 	icaltimezone *timezone;
 	const gchar *default_tzloc = NULL;
@@ -161,7 +98,6 @@ cal_shell_view_execute_search (EShellView *shell_view)
 	time_t end_range;
 	time_t now_time;
 	gboolean range_search;
-	gchar *start, *end;
 	gchar *query;
 	gchar *temp;
 	gint value;
@@ -173,13 +109,12 @@ cal_shell_view_execute_search (EShellView *shell_view)
 	shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
 
 	cal_shell_content = E_CAL_SHELL_CONTENT (shell_content);
-	cal_shell_sidebar = E_CAL_SHELL_SIDEBAR (shell_sidebar);
+	cal_shell_sidebar = E_CAL_BASE_SHELL_SIDEBAR (shell_sidebar);
 
 	searchbar = e_cal_shell_content_get_searchbar (cal_shell_content);
 
-	calendar = e_cal_shell_content_get_calendar (cal_shell_content);
-	model = gnome_calendar_get_model (calendar);
-	timezone = e_cal_model_get_timezone (model);
+	data_model = e_cal_base_shell_content_get_data_model (E_CAL_BASE_SHELL_CONTENT (cal_shell_content));
+	timezone = e_cal_data_model_get_timezone (data_model);
 	current_time = icaltime_current_time_with_zone (timezone);
 	now_time = time_day_begin (icaltime_as_timet (current_time));
 
@@ -254,34 +189,12 @@ cal_shell_view_execute_search (EShellView *shell_view)
 			/* Show a year's worth of appointments. */
 			start_range = now_time;
 			end_range = time_day_end (time_add_day (start_range, 365));
-			start = isodate_from_time_t (start_range);
-			end = isodate_from_time_t (end_range);
-
-			temp = g_strdup_printf (
-				"(and %s (occur-in-time-range? "
-				"(make-time \"%s\") "
-				"(make-time \"%s\") \"%s\"))",
-				query, start, end, default_tzloc);
-			g_free (query);
-			query = temp;
-
 			range_search = TRUE;
 			break;
 
 		case CALENDAR_FILTER_NEXT_7_DAYS_APPOINTMENTS:
 			start_range = now_time;
 			end_range = time_day_end (time_add_day (start_range, 7));
-			start = isodate_from_time_t (start_range);
-			end = isodate_from_time_t (end_range);
-
-			temp = g_strdup_printf (
-				"(and %s (occur-in-time-range? "
-				"(make-time \"%s\") "
-				"(make-time \"%s\") \"%s\"))",
-				query, start, end, default_tzloc);
-			g_free (query);
-			query = temp;
-
 			range_search = TRUE;
 			break;
 
@@ -299,32 +212,35 @@ cal_shell_view_execute_search (EShellView *shell_view)
 
 			categories = e_util_dup_searchable_categories ();
 			category_name = g_list_nth_data (categories, value);
-			g_list_free_full (categories, g_free);
 
 			temp = g_strdup_printf (
 				"(and (has-categories? \"%s\") %s)",
 				category_name, query);
 			g_free (query);
 			query = temp;
+
+			g_list_free_full (categories, g_free);
 			break;
 		}
 	}
 
-	date_navigator = e_cal_shell_sidebar_get_date_navigator (cal_shell_sidebar);
+	calendar = e_cal_base_shell_sidebar_get_date_navigator (cal_shell_sidebar);
 
 	if (range_search) {
 		/* Switch to list view and hide the date navigator. */
 		action = GTK_RADIO_ACTION (ACTION (CALENDAR_VIEW_LIST));
 		gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
-		gtk_widget_hide (GTK_WIDGET (date_navigator));
+		gtk_widget_hide (GTK_WIDGET (calendar));
 	} else {
 		/* Ensure the date navigator is visible. */
-		gtk_widget_show (GTK_WIDGET (date_navigator));
+		gtk_widget_show (GTK_WIDGET (calendar));
+		e_cal_shell_content_get_current_range (cal_shell_content, &start_range, &end_range);
+		end_range = time_day_end (end_range) - 1;
 	}
 
 	/* Submit the query. */
-	gnome_calendar_set_search_query (
-		calendar, query, range_search, start_range, end_range);
+	e_cal_shell_content_update_filters (cal_shell_content, query, start_range, end_range);
+
 	g_free (query);
 
 	/* Update actions so Find Prev/Next/Stop
@@ -343,13 +259,12 @@ cal_shell_view_update_actions (EShellView *shell_view)
 	EShell *shell;
 	ESource *source;
 	ESourceRegistry *registry;
-	GnomeCalendar *calendar;
 	ECalendarView *cal_view;
 	EMemoTable *memo_table;
 	ETaskTable *task_table;
-	ECalModel *model;
+	ECalDataModel *data_model;
 	GtkAction *action;
-	const gchar *model_sexp;
+	gchar *data_filter;
 	gboolean is_searching;
 	gboolean sensitive;
 	guint32 state;
@@ -389,52 +304,51 @@ cal_shell_view_update_actions (EShellView *shell_view)
 	}
 
 	cal_shell_content = priv->cal_shell_content;
-	calendar = e_cal_shell_content_get_calendar (cal_shell_content);
-	cal_view = gnome_calendar_get_calendar_view (calendar, gnome_calendar_get_view (calendar));
+	cal_view = e_cal_shell_content_get_current_calendar_view (cal_shell_content);
 	memo_table = e_cal_shell_content_get_memo_table (cal_shell_content);
 	task_table = e_cal_shell_content_get_task_table (cal_shell_content);
-	model = gnome_calendar_get_model (calendar);
-	model_sexp = e_cal_model_get_search_query (model);
-	is_searching = model_sexp && *model_sexp &&
-		g_strcmp0 (model_sexp, "#t") != 0 &&
-		g_strcmp0 (model_sexp, "(contains? \"summary\"  \"\")") != 0;
+	data_model = e_cal_base_shell_content_get_data_model (E_CAL_BASE_SHELL_CONTENT (cal_shell_content));
+	data_filter = e_cal_data_model_dup_filter (data_model);
+	is_searching = data_filter && *data_filter &&
+		g_strcmp0 (data_filter, "#t") != 0 &&
+		g_strcmp0 (data_filter, "(contains? \"summary\"  \"\")") != 0;
+	g_free (data_filter);
 
 	shell_content = e_shell_view_get_shell_content (shell_view);
 	state = e_shell_content_check_state (shell_content);
 
 	single_event_selected =
-		(state & E_CAL_SHELL_CONTENT_SELECTION_SINGLE);
+		(state & E_CAL_BASE_SHELL_CONTENT_SELECTION_SINGLE);
 	multiple_events_selected =
-		(state & E_CAL_SHELL_CONTENT_SELECTION_MULTIPLE);
+		(state & E_CAL_BASE_SHELL_CONTENT_SELECTION_MULTIPLE);
 	selection_is_editable =
-		(state & E_CAL_SHELL_CONTENT_SELECTION_IS_EDITABLE);
+		(state & E_CAL_BASE_SHELL_CONTENT_SELECTION_IS_EDITABLE);
 	selection_is_instance =
-		(state & E_CAL_SHELL_CONTENT_SELECTION_IS_INSTANCE);
+		(state & E_CAL_BASE_SHELL_CONTENT_SELECTION_IS_INSTANCE);
 	selection_is_meeting =
-		(state & E_CAL_SHELL_CONTENT_SELECTION_IS_MEETING);
+		(state & E_CAL_BASE_SHELL_CONTENT_SELECTION_IS_MEETING);
 	selection_is_recurring =
-		(state & E_CAL_SHELL_CONTENT_SELECTION_IS_RECURRING);
+		(state & E_CAL_BASE_SHELL_CONTENT_SELECTION_IS_RECURRING);
 	selection_can_delegate =
-		(state & E_CAL_SHELL_CONTENT_SELECTION_CAN_DELEGATE);
+		(state & E_CAL_BASE_SHELL_CONTENT_SELECTION_CAN_DELEGATE);
 
 	shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
 	state = e_shell_sidebar_check_state (shell_sidebar);
 
 	has_primary_source =
-		(state & E_CAL_SHELL_SIDEBAR_HAS_PRIMARY_SOURCE);
+		(state & E_CAL_BASE_SHELL_SIDEBAR_HAS_PRIMARY_SOURCE);
 	primary_source_is_writable =
-		(state & E_CAL_SHELL_SIDEBAR_PRIMARY_SOURCE_IS_WRITABLE);
+		(state & E_CAL_BASE_SHELL_SIDEBAR_PRIMARY_SOURCE_IS_WRITABLE);
 	primary_source_is_removable =
-		(state & E_CAL_SHELL_SIDEBAR_PRIMARY_SOURCE_IS_REMOVABLE);
+		(state & E_CAL_BASE_SHELL_SIDEBAR_PRIMARY_SOURCE_IS_REMOVABLE);
 	primary_source_is_remote_deletable =
-		(state & E_CAL_SHELL_SIDEBAR_PRIMARY_SOURCE_IS_REMOTE_DELETABLE);
+		(state & E_CAL_BASE_SHELL_SIDEBAR_PRIMARY_SOURCE_IS_REMOTE_DELETABLE);
 	primary_source_in_collection =
-		(state & E_CAL_SHELL_SIDEBAR_PRIMARY_SOURCE_IN_COLLECTION);
+		(state & E_CAL_BASE_SHELL_SIDEBAR_PRIMARY_SOURCE_IN_COLLECTION);
 	refresh_supported =
-		(state & E_CAL_SHELL_SIDEBAR_SOURCE_SUPPORTS_REFRESH);
+		(state & E_CAL_BASE_SHELL_SIDEBAR_SOURCE_SUPPORTS_REFRESH);
 
-	any_events_selected =
-		(single_event_selected || multiple_events_selected);
+	any_events_selected = (single_event_selected || multiple_events_selected);
 
 	action = ACTION (CALENDAR_COPY);
 	sensitive = has_primary_source;
@@ -574,11 +488,76 @@ cal_shell_view_update_actions (EShellView *shell_view)
 	}
 }
 
+static void
+cal_shell_view_dispose (GObject *object)
+{
+	e_cal_shell_view_private_dispose (E_CAL_SHELL_VIEW (object));
+
+	/* Chain up to parent's dispose() method. */
+	G_OBJECT_CLASS (e_cal_shell_view_parent_class)->dispose (object);
+}
+
+static void
+cal_shell_view_finalize (GObject *object)
+{
+	e_cal_shell_view_private_finalize (E_CAL_SHELL_VIEW (object));
+
+	/* Chain up to parent's finalize() method. */
+	G_OBJECT_CLASS (e_cal_shell_view_parent_class)->finalize (object);
+}
+
+static void
+cal_shell_view_constructed (GObject *object)
+{
+	EShell *shell;
+	EShellView *shell_view;
+	EShellWindow *shell_window;
+	EShellSearchbar *searchbar;
+	ECalShellView *cal_shell_view;
+	ECalShellContent *cal_shell_content;
+	GtkWidget *container;
+	GtkWidget *widget;
+	gulong handler_id;
+
+	/* Chain up to parent's constructed() method. */
+	G_OBJECT_CLASS (e_cal_shell_view_parent_class)->constructed (object);
+
+	cal_shell_view = E_CAL_SHELL_VIEW (object);
+	e_cal_shell_view_private_constructed (cal_shell_view);
+
+	shell_view = E_SHELL_VIEW (cal_shell_view);
+	shell_window = e_shell_view_get_shell_window (shell_view);
+	shell = e_shell_window_get_shell (shell_window);
+
+	cal_shell_content = cal_shell_view->priv->cal_shell_content;
+	searchbar = e_cal_shell_content_get_searchbar (cal_shell_content);
+	container = e_shell_searchbar_get_search_box (searchbar);
+
+	widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	cal_shell_view_add_action_button (
+		GTK_BOX (widget), ACTION (CALENDAR_SEARCH_PREV));
+	cal_shell_view_add_action_button (
+		GTK_BOX (widget), ACTION (CALENDAR_SEARCH_NEXT));
+	cal_shell_view_add_action_button (
+		GTK_BOX (widget), ACTION (CALENDAR_SEARCH_STOP));
+	gtk_container_add (GTK_CONTAINER (container), widget);
+	gtk_widget_show (widget);
+
+	handler_id = g_signal_connect (
+		shell, "prepare-for-quit",
+		G_CALLBACK (cal_shell_view_prepare_for_quit_cb),
+		cal_shell_view);
+
+	cal_shell_view->priv->shell = g_object_ref (shell);
+	cal_shell_view->priv->prepare_for_quit_handler_id = handler_id;
+}
+
 static void
 e_cal_shell_view_class_init (ECalShellViewClass *class)
 {
 	GObjectClass *object_class;
 	EShellViewClass *shell_view_class;
+	ECalBaseShellViewClass *cal_base_shell_view_class;
 
 	g_type_class_add_private (class, sizeof (ECalShellViewPrivate));
 
@@ -595,16 +574,21 @@ e_cal_shell_view_class_init (ECalShellViewClass *class)
 	shell_view_class->search_options = "/calendar-search-options";
 	shell_view_class->search_rules = "caltypes.xml";
 	shell_view_class->new_shell_content = e_cal_shell_content_new;
-	shell_view_class->new_shell_sidebar = e_cal_shell_sidebar_new;
+	shell_view_class->new_shell_sidebar = e_cal_base_shell_sidebar_new;
 	shell_view_class->execute_search = cal_shell_view_execute_search;
 	shell_view_class->update_actions = cal_shell_view_update_actions;
 
+	cal_base_shell_view_class = E_CAL_BASE_SHELL_VIEW_CLASS (class);
+	cal_base_shell_view_class->source_type = E_CAL_CLIENT_SOURCE_TYPE_EVENTS;
+
 	/* Ensure the GalView types we need are registered. */
 	g_type_ensure (GAL_TYPE_VIEW_CALENDAR_DAY);
 	g_type_ensure (GAL_TYPE_VIEW_CALENDAR_WORK_WEEK);
 	g_type_ensure (GAL_TYPE_VIEW_CALENDAR_WEEK);
 	g_type_ensure (GAL_TYPE_VIEW_CALENDAR_MONTH);
 	g_type_ensure (GAL_TYPE_VIEW_ETABLE);
+
+	e_calendar_a11y_init ();
 }
 
 static void
@@ -615,8 +599,7 @@ e_cal_shell_view_class_finalize (ECalShellViewClass *class)
 static void
 e_cal_shell_view_init (ECalShellView *cal_shell_view)
 {
-	cal_shell_view->priv =
-		E_CAL_SHELL_VIEW_GET_PRIVATE (cal_shell_view);
+	cal_shell_view->priv = E_CAL_SHELL_VIEW_GET_PRIVATE (cal_shell_view);
 
 	e_cal_shell_view_private_init (cal_shell_view);
 }
@@ -629,87 +612,3 @@ e_cal_shell_view_type_register (GTypeModule *type_module)
 	 *     order to register types from a separate compilation unit. */
 	e_cal_shell_view_register_type (type_module);
 }
-
-static void
-cal_shell_view_allow_auth_prompt_and_refresh_done_cb (GObject *source_object,
-						      GAsyncResult *result,
-						      gpointer user_data)
-{
-	EClient *client;
-	EActivity *activity;
-	EAlertSink *alert_sink;
-	ESource *source;
-	const gchar *display_name;
-	GError *local_error = NULL;
-
-	g_return_if_fail (E_IS_CAL_CLIENT (source_object));
-
-	client = E_CLIENT (source_object);
-	source = e_client_get_source (client);
-	activity = user_data;
-	alert_sink = e_activity_get_alert_sink (activity);
-	display_name = e_source_get_display_name (source);
-
-	e_util_allow_auth_prompt_and_refresh_client_finish (client, result, &local_error);
-
-	if (e_activity_handle_cancellation (activity, local_error)) {
-		g_error_free (local_error);
-
-	} else if (local_error != NULL) {
-		const gchar *error_message;
-
-		switch (e_cal_client_get_source_type (E_CAL_CLIENT (client))) {
-		default:
-		case E_CAL_CLIENT_SOURCE_TYPE_EVENTS:
-			error_message = "calendar:refresh-error-events";
-			break;
-		case E_CAL_CLIENT_SOURCE_TYPE_TASKS:
-			error_message = "calendar:refresh-error-tasks";
-			break;
-		case E_CAL_CLIENT_SOURCE_TYPE_MEMOS:
-			error_message = "calendar:refresh-error-memos";
-			break;
-		}
-		e_alert_submit (
-			alert_sink,
-			error_message,
-			display_name, local_error->message, NULL);
-		g_error_free (local_error);
-
-	} else {
-		e_activity_set_state (activity, E_ACTIVITY_COMPLETED);
-	}
-
-	g_clear_object (&activity);
-}
-
-void
-e_cal_shell_view_allow_auth_prompt_and_refresh (EShellView *shell_view,
-						EClient *client)
-{
-	EShellBackend *shell_backend;
-	EShellContent *shell_content;
-	EActivity *activity;
-	EAlertSink *alert_sink;
-	GCancellable *cancellable;
-
-	g_return_if_fail (E_IS_SHELL_VIEW (shell_view));
-	g_return_if_fail (E_IS_CLIENT (client));
-
-	shell_backend = e_shell_view_get_shell_backend (shell_view);
-	shell_content = e_shell_view_get_shell_content (shell_view);
-
-	alert_sink = E_ALERT_SINK (shell_content);
-	activity = e_activity_new ();
-	cancellable = g_cancellable_new ();
-
-	e_activity_set_alert_sink (activity, alert_sink);
-	e_activity_set_cancellable (activity, cancellable);
-
-	e_util_allow_auth_prompt_and_refresh_client (client, cancellable,
-		cal_shell_view_allow_auth_prompt_and_refresh_done_cb, activity);
-
-	e_shell_backend_add_activity (shell_backend, activity);
-
-	g_object_unref (cancellable);
-}
