@@ -135,6 +135,20 @@ void		e_shell_window_set_toolbar_visible
 						(EShellWindow *shell_window,
 						 gboolean toolbar_visible);
 
+/* Helper function to open clients from shell's client cache in a dedicated
+   thread with a callback being called in the main thread */
+
+typedef void (* EShellWindowConnetClientFunc)	(EShellWindow *shell_window,
+						 EClient *client,
+						 gpointer user_data);
+
+void		e_shell_window_connect_client	(EShellWindow *shell_window,
+						 ESource *source,
+						 const gchar *extension_name,
+						 EShellWindowConnetClientFunc connected_cb,
+						 gpointer user_data,
+						 GDestroyNotify destroy_user_data);
+
 /* These should be called from the shell backend's window_created() handler. */
 
 void		e_shell_window_register_new_item_actions
